@@ -40,24 +40,24 @@ def show(level,
          node,
          colors, verbose,
          cmap,
-         filehandle, width, max_depth,
-         indent_fill, line_format, unindent_fill, level_fill) :
+         filehandle, width,
+         indent_fill, line_format, unindent_fill, level_fill,
+         hide_collapsed) :
 
     assert(node          != None)
-    assert(type(colors)  == bool)
-    assert(type(verbose) == bool)
+    assert(isinstance(colors, bool))
+    assert(isinstance(verbose, bool))
     assert(filehandle    != None)
     assert(width         >= 0)
-    assert(max_depth     >= -1)
     assert(indent_fill   != None)
     assert(line_format   != None)
     assert(unindent_fill != None)
     assert(level_fill    != None)
 
     # Dump the current node
-    if (type(node) == Root.Root) :
+    if (isinstance(node, Root.Root)) :
         pass
-    elif (type(node) == Entry.Entry) :
+    elif (isinstance(node, Entry.Entry)) :
         e = node
 
         if not (('visible' in e.flags)   or
@@ -87,7 +87,7 @@ def show(level,
             else :
                 priority = "unknown"
 
-            if (e.done()) :
+            if (e.done) :
                 status = "complete"
             else :
                 status = "incomplete"
@@ -97,6 +97,8 @@ def show(level,
             else :
                 comment = ""
 
+            depth = str(e.depth)
+
             id_temp = e.id
             id_absolute = str(id_temp)
             # Remove leading '0.' (we don't print anything related
@@ -140,12 +142,17 @@ def show(level,
             t = re.sub('%e', end,                       t)
             t = re.sub('%p', color_text(priority),      t)
             t = re.sub('%c', comment,                   t)
+            t = re.sub('%d', depth,                     t)
             # Always substitute text at last in order to avoid re-substitutions
             # if text contains %i, %s, %e, %p, %c and so on
             #
             # If line is set as "collapsed", substitute text with "..."
             if ('collapsed' in e.flags) :
-                t = re.sub('%t', color_text('...'), t)
+                # XXX FIXME: Awful hack
+                if (hide_collapsed) :
+                    t = ''
+                else :
+                    t = re.sub('%t', color_text('...'), t)
             else :
                 t = re.sub('%t', color_text(text),  t)
 
@@ -178,25 +185,22 @@ def show(level,
 
     # Finally handle node children
     assert(hasattr(node, "children"))
-    if ((len(node.children()) > 0)   and
-        (max_depth != 0)             and
+    if ((len(node.children) > 0)      and
         (('visible' in node.flags)    or
          ('collapsed' in node.flags))) :
         debug("Indenting more")
         filehandle.write(indent_fill)
 
         debug("Handling children")
-        for j in node.children() :
-            if (max_depth >= 1) :
-                max_depth = max_depth - 1
-
+        for j in node.children :
             show(level + 1,
                  j,
                  colors, verbose,
                  cmap,
-                 filehandle, width, max_depth,
+                 filehandle, width,
                  indent_fill, line_format,
-                 unindent_fill, level_fill)
+                 unindent_fill, level_fill,
+                 hide_collapsed)
 
         debug("Indenting less")
         filehandle.write(unindent_fill)
@@ -210,10 +214,10 @@ def mark(node, filter) :
     marked = 0
     node.flags = []
 
-    if (len(node.children()) > 0) :
-        debug("Marking " + str(len(node.children())) + " children")
+    if (len(node.children) > 0) :
+        debug("Marking " + str(len(node.children)) + " children")
 
-        for i in node.children() :
+        for i in node.children :
             m       = 0
             node, m = mark(i, filter)
             marked  = marked + m
@@ -225,15 +229,15 @@ def mark(node, filter) :
               "' has "  +  str(marked) +
               " children that match filter")
 
-    if (type(node) == Root.Root) :
+    if (isinstance(node, Root.Root)) :
         if (marked > 0) :
             debug("Entry `"                               + str(node)   +
                   "' has children those matches filter `" + str(filter) +
                   "' marking it as collapsed")
             node.flags = ['collapsed']
 
-    elif (type(node) == Entry.Entry) :
-        match = filter.function(node)
+    elif (isinstance(node, Entry.Entry)) :
+        match = filter.evaluate(node)
 
         if ((marked > 0) and (match == False)) :
             debug("Entry `"                               + str(node)   +
@@ -270,6 +274,7 @@ class SubCommand(Command) :
                 "  %I  index (absolute)",
                 "  %i  index (relative)",
                 "  %c  comment",
+                "  %d  depth",
                 "",
                 "FILTER  " + Filter.help(),
                 "ID      " + ID.help(),
@@ -337,11 +342,10 @@ class SubCommand(Command) :
                            dest   = "filter",
                            help   = "specify selection filter")
         Command.add_option(self,
-                           "-D", "--max-depth",
-                           action = "store",
-                           type   = "string",
-                           dest   = "max_depth",
-                           help   = "specify maximum show depth")
+                           "-H", "--hide-collapsed",
+                           action = "store_true",
+                           dest   = "hide",
+                           help   = "hide collapsed entries")
 
         (opts, args) = Command.parse_args(self, arguments)
         if (len(args) > 0) :
@@ -371,7 +375,7 @@ class SubCommand(Command) :
         except :
             debug("No width configuration found")
 
-        # Ovveride width with parameters (if present)
+        # Override width with parameters (if present)
         try :
             if (opts.width != None) :
                 width = int(opts.width)
@@ -384,29 +388,29 @@ class SubCommand(Command) :
             t     = Terminal.Terminal(stream_out = filehandle)
             width = t.columns
 
-        assert(type(width) == int)
+        assert(isinstance(width, int))
         assert(width >= 0)
 
         debug("Output width is " + str(width))
 
-        # Handle depth...
-        max_depth = -1
+        # Handle hide-collapsed
+        hide_collapsed = None
 
-        try:
-            if (opts.max_depth != None) :
-               max_depth = int(opts.max_depth)
+        # Get hide-collapsed from configuration (if present)
+        try :
+            hide_collapsed = configuration.get(PROGRAM_NAME,
+                                               'hide-collapsed',
+                                               raw = True)
         except :
-            raise Exceptions.WrongParameter("depth must be greater or equal "
-                                            "than 0")
+            debug("No hide-collapsed configuration found")
 
-        if ((opts.max_depth != None) and (max_depth < 0)) :
-            raise Exceptions.WrongParameter("depth must be greater or equal "
-                                            "than 0")
+        # Override hide-collapsed with parameters (if present)
+        try :
+            if (opts.hide != None) :
+                hide_collapsed = bool(opts.hide)
+        except :
+            raise Exceptions.WrongParameter("hide-collapsed must be boolean")
 
-        assert(type(max_depth) == int)
-        assert(max_depth >= -1)
-
-        debug("Max-depth is: `" + str(max_depth) + "'")
 
         try :
             colors = configuration.get(PROGRAM_NAME, 'colors', raw = True)
@@ -434,12 +438,12 @@ class SubCommand(Command) :
             indent_fill   = ""
             line_format     = "%i %t\n  [%c]\n  (%s, %e, %p)\n"
             unindent_fill = ""
-            level_fill    = "  "
+            level_fill    = "    "
         else :
             indent_fill   = ""
             line_format     = "%i %t\n"
             unindent_fill = ""
-            level_fill    = "  "
+            level_fill    = "    "
 
         if (opts.indent_fill != None) :
             indent_fill = opts.indent_fill
@@ -463,7 +467,7 @@ class SubCommand(Command) :
         debug("Level-fill is: `" + level_fill + "'")
 
         # Build the filter
-        filter_text = "all"
+        filter_text = "not done"
         if (opts.filter != None) :
             filter_text = opts.filter
         filter = Filter.Filter(filter_text)
@@ -487,11 +491,11 @@ class SubCommand(Command) :
         #
 
         cmap = {
-            Priority.Priority.PRIORITY_VERYHIGH : ANSI.bright_red,
-            Priority.Priority.PRIORITY_HIGH     : ANSI.bright_yellow,
-            Priority.Priority.PRIORITY_MEDIUM   : ANSI.bright_white,
-            Priority.Priority.PRIORITY_LOW      : ANSI.normal_cyan,
-            Priority.Priority.PRIORITY_VERYLOW  : ANSI.normal_blue,
+            Priority.PRIORITY_VERYHIGH : ANSI.bright_red,
+            Priority.PRIORITY_HIGH     : ANSI.bright_yellow,
+            Priority.PRIORITY_MEDIUM   : ANSI.bright_white,
+            Priority.PRIORITY_LOW      : ANSI.normal_cyan,
+            Priority.PRIORITY_VERYLOW  : ANSI.normal_blue,
             }
 
         # Marking nodes that match filters
@@ -504,8 +508,9 @@ class SubCommand(Command) :
              node,
              colors, verbose,
              cmap,
-             filehandle, width, max_depth,
-             indent_fill, line_format, unindent_fill, level_fill)
+             filehandle, width,
+             indent_fill, line_format, unindent_fill, level_fill,
+             hide_collapsed)
         #filehandle.write(unindent_fill)
 
         # Avoid closing precious filehandles
