@@ -32,22 +32,25 @@ try :
     import Move
     import Remove
     import Show
-except ImportError :
-    # XXX FIXME: Add better error reporting ....
-    print("Cannot import package's commands ...")
+except ImportError, e :
+    try :
+        why = "(" + str(e) + ")"
+    except :
+        why = ""
+    print("Cannot import package's commands " + why + " ...")
     sys.exit(-1)
 
 commands = {
-    'add'      : Add    . SubCommand(),
-    'clean'    : Clean  . SubCommand(),
-    'config'   : Config . SubCommand(),
-    'mark'     : Mark   . SubCommand(),
-    'edit'     : Edit   . SubCommand(),
-    'fix'      : Fix    . SubCommand(),
-    'init'     : Init   . SubCommand(),
-    'move'     : Move   . SubCommand(),
-    'remove'   : Remove . SubCommand(),
-    'show'     : Show   . SubCommand(),
+    'add'    : Add    . SubCommand(),
+    'clean'  : Clean  . SubCommand(),
+    'config' : Config . SubCommand(),
+    'mark'   : Mark   . SubCommand(),
+    'edit'   : Edit   . SubCommand(),
+    'fix'    : Fix    . SubCommand(),
+    'init'   : Init   . SubCommand(),
+    'move'   : Move   . SubCommand(),
+    'remove' : Remove . SubCommand(),
+    'show'   : Show   . SubCommand(),
     }
 
 # Test
