@@ -30,7 +30,7 @@ from   Trace import *
 class EBase(Exception) :
     def __init__(self, message) :
         assert(message != None)
-        assert(type(message) == str)
+        assert(isinstance(message, str))
         self.__message = message
 
     def __str__(self) :
@@ -38,13 +38,6 @@ class EBase(Exception) :
 
     __repr__ = __str__
 
-#
-# OS related exceptions
-#
-class EOS(EBase) :
-    def __init__(self, message) :
-        EBase.__init__(self, message)
-
 #
 # Time related exceptions
 #
@@ -63,9 +56,17 @@ class EPriority(EBase) :
     def __init__(self, message) :
         EBase.__init__(self, message)
 
-class UnknownPriority(EPriority) :
+class UnknownPriorityName(EPriority) :
     def __init__(self, message) :
-        EPriority.__init__(self, "unknown priority `" + message + "'")
+        EPriority.__init__(self, "unknown priority name `" + message + "'")
+
+class UnknownPriorityValue(EPriority) :
+    def __init__(self, message) :
+        EPriority.__init__(self, "unknown priority value `" + message + "'")
+
+class WrongPriorityFormat(EPriority) :
+    def __init__(self, message) :
+        EPriority.__init__(self, "wrong priority format `" + message + "'")
 
 #
 # Database related exceptions
@@ -102,7 +103,7 @@ class CorruptedDatabase(EDatabase) :
 class ProblemsReading(EDatabase) :
     def __init__(self, name, message) :
         tmp = ""
-        if (message != None) :
+        if (message != None and len(message) != 0) :
             tmp = ", " + message
         EDatabase.__init__(self,
                            "problems reading database "
@@ -111,7 +112,7 @@ class ProblemsReading(EDatabase) :
 class ProblemsWriting(EDatabase) :
     def __init__(self, name, message) :
         tmp = ""
-        if (message != None) :
+        if (message != None and len(message) != 0) :
             tmp = ", " + message
         EDatabase.__init__(self,
                            "problems writing database "
@@ -132,6 +133,10 @@ class CannotRead(EFile) :
     def __init__(self, message) :
         EFile.__init__(self, "cannot read from file `" + message + "'")
 
+class CannotRemove(EFile) :
+    def __init__(self, message) :
+        EFile.__init__(self, "cannot remove file `" + message + "'")
+
 #
 # ID related exceptions
 #
@@ -186,7 +191,7 @@ class EParameters(EBase) :
 class ExplicitExit(EParameters) :
     def __init__(self, message, code) :
         assert(code != None)
-        assert(type(code) == int)
+        assert(isinstance(code, int))
 
         #
         # NOTE:
@@ -287,6 +292,17 @@ class UnknownEnum(EEnum) :
     def __init__(self, message) :
         EEnum.__init__(self, "no enumeration for `" + message + "'")
 
+#
+# Constant related exceptions
+#
+class EConst(EBase) :
+    def __init__(self, message) :
+        EBase.__init__(self, message)
+
+class ReadOnlyConstant(EBase) :
+    def __init__(self, message) :
+        EConst.__init__(self, "variable `' is read-only")
+
 #
 # Expression related exceptions
 #
@@ -296,26 +312,16 @@ class EExpression(EBase) :
 
 class InvalidExpression(EExpression) :
     def __init__(self, message) :
-        EEnum.__init__(self, "invalid `" + message + "' expression")
+        EExpression.__init__(self, "invalid expression `" + message + "'")
+
+class InvalidExpressionType(EExpression) :
+    def __init__(self, message) :
+        EExpression.__init__(self, "invalid expression type `" + message + "'")
 
-#
-# Expression lexer related exceptions
-#
 class InvalidToken(EExpression) :
     def __init__(self, message) :
         EExpression.__init__(self, "invalid token `" + message + "'")
 
-#
-# Expression parser related exceptions
-#
-class InvalidSyntax(EExpression) :
-    def __init__(self, message) :
-        EExpression.__init__(self, "invalid syntax `" + message + "'")
-
-class InvalidIdentifier(EExpression) :
-    def __init__(self, message) :
-        EExpression.__init__(self, "invalid identifier `" + message + "'")
-
 # Test
 if (__name__ == '__main__') :
     debug("Test completed")
